@@ -28,23 +28,16 @@
 
 #include <QLabel>
 
-namespace EventViews
-{
-
+namespace EventViews {
 class DecorationLabel : public QLabel
 {
     Q_OBJECT
 public:
-    explicit DecorationLabel(EventViews::CalendarDecoration::Element *e,
-                             QWidget *parent = nullptr);
+    explicit DecorationLabel(EventViews::CalendarDecoration::Element *e, QWidget *parent = nullptr);
 
-    explicit DecorationLabel(const QString &shortText,
-                             const QString &longText = QString(),
-                             const QString &extensiveText = QString(),
-                             const QPixmap &pixmap = QPixmap(),
-                             const QUrl &url = QUrl(),
-                             QWidget *parent = nullptr);
-    ~DecorationLabel();
+    explicit DecorationLabel(const QString &shortText, const QString &longText = QString(), const QString &extensiveText = QString(), const QPixmap &pixmap = QPixmap(),
+                             const QUrl &url = QUrl(), QWidget *parent = nullptr);
+    ~DecorationLabel() override;
 
 public Q_SLOTS:
     void setExtensiveText(const QString &);
@@ -64,12 +57,11 @@ protected:
     void mouseReleaseEvent(QMouseEvent *) override;
     virtual void squeezeContentsToLabel();
     bool mAutomaticSqueeze;
-    EventViews::CalendarDecoration::Element *mDecorationElement;
+    EventViews::CalendarDecoration::Element *mDecorationElement = nullptr;
     QString mShortText, mLongText, mExtensiveText;
     QPixmap mPixmap;
     QUrl mUrl;
 };
-
 }
 
 #endif
